==> vsquickview-0.2.3.tar.gz: vsquickview-0.2.3/vsquickview/__init__.py <==
# vsquickview
# Copyright (c) Akatsumekusa and contributors

# ---------------------------------------------------------------------
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ---------------------------------------------------------------------

import __main__
if not __main__.__name__ == "__vapoursynth__":
    from .vsquickview import View, RemoveView, SetFrame, SetIndex, SetPreviewGroup, ClearPreviewGroup, Show, Hide
else:
    from .fakevsquickview import View, RemoveView, SetFrame, SetIndex, SetPreviewGroup, ClearPreviewGroup, Show, Hide

__version__ = "0.2.3"

==> vsquickview-0.2.5.tar.gz: vsquickview-0.2.5/vsquickview/__init__.py <==
# vsquickview
# Copyright (c) Akatsumekusa and contributors

# ---------------------------------------------------------------------
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ---------------------------------------------------------------------

import __main__
if not __main__.__name__ == "__vapoursynth__":
    from .vsquickview import View, \
                             RemoveView, \
                             SetFrame, \
                             SetIndex, \
                             SetPreviewGroup, \
                             ClearPreviewGroup, \
                             PreviewGroup, \
                             Show, \
                             Hide
else:
    from .fakevsquickview import View, \
                                 RemoveView, \
                                 SetFrame, \
                                 SetIndex, \
                                 SetPreviewGroup, \
                                 ClearPreviewGroup, \
                                 PreviewGroup, \
                                 Show, \
                                 Hide

__version__ = "0.2.5"
